# Experimental toolkit for ease.ml/datascope

[![PyPI version](https://badge.fury.io/py/datascope-experiments.svg)](https://badge.fury.io/py/datascope-experiments)

This module is used for running experiments on top of [ease.ml/datascope](https://ease.ml/datascope). It is also
made to be extensible in order to validate datascope against novel pipelines and experimental scenarios.
